Struct Memchr2

struct Memchr2<'h> { ... }

An iterator over all occurrences of two possible bytes in a haystack.

This iterator implements DoubleEndedIterator, which means it can also be used to find occurrences in reverse order.

This iterator is created by the memchr2_iter or [memrchr2_iter] functions. It can also be created with the Memchr2::new method.

The lifetime parameter 'h refers to the lifetime of the haystack being searched.

Implementations

impl<'h> Memchr2<'h>

fn new(needle1: u8, needle2: u8, haystack: &'h [u8]) -> Memchr2<'h>

Returns an iterator over all occurrences of the needle bytes in the given haystack.

The iterator returned implements DoubleEndedIterator. This means it can also be used to find occurrences in reverse order.

impl<'h> Clone for Memchr2<'h>

fn clone(self: &Self) -> Memchr2<'h>

impl<'h> Debug for Memchr2<'h>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'h> DoubleEndedIterator for Memchr2<'h>

fn next_back(self: &mut Self) -> Option<usize>

impl<'h> Freeze for Memchr2<'h>

impl<'h> FusedIterator for Memchr2<'h>

impl<'h> Iterator for Memchr2<'h>

fn next(self: &mut Self) -> Option<usize>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<'h> RefUnwindSafe for Memchr2<'h>

impl<'h> Send for Memchr2<'h>

impl<'h> Sync for Memchr2<'h>

impl<'h> Unpin for Memchr2<'h>

impl<'h> UnsafeUnpin for Memchr2<'h>

impl<'h> UnwindSafe for Memchr2<'h>

impl<I> IntoIterator for Memchr2<'h>

fn into_iter(self: Self) -> I

impl<T> Any for Memchr2<'h>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Memchr2<'h>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Memchr2<'h>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Memchr2<'h>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Memchr2<'h>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for Memchr2<'h>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for Memchr2<'h>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Memchr2<'h>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Memchr2<'h>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>