Struct Memchr
struct Memchr<'h> { ... }
An iterator over all occurrences of a single byte in a haystack.
This iterator implements DoubleEndedIterator, which means it can also be
used to find occurrences in reverse order.
This iterator is created by the memchr_iter or [memrchr_iter]
functions. It can also be created with the Memchr::new method.
The lifetime parameter 'h refers to the lifetime of the haystack being
searched.
Implementations
impl<'h> Memchr<'h>
fn new(needle1: u8, haystack: &'h [u8]) -> Memchr<'h>Returns an iterator over all occurrences of the needle byte in the given haystack.
The iterator returned implements
DoubleEndedIterator. This means it can also be used to find occurrences in reverse order.
impl<'h> Clone for Memchr<'h>
fn clone(self: &Self) -> Memchr<'h>
impl<'h> Debug for Memchr<'h>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'h> DoubleEndedIterator for Memchr<'h>
fn next_back(self: &mut Self) -> Option<usize>
impl<'h> Freeze for Memchr<'h>
impl<'h> FusedIterator for Memchr<'h>
impl<'h> Iterator for Memchr<'h>
fn next(self: &mut Self) -> Option<usize>fn count(self: Self) -> usizefn size_hint(self: &Self) -> (usize, Option<usize>)
impl<'h> RefUnwindSafe for Memchr<'h>
impl<'h> Send for Memchr<'h>
impl<'h> Sync for Memchr<'h>
impl<'h> Unpin for Memchr<'h>
impl<'h> UnsafeUnpin for Memchr<'h>
impl<'h> UnwindSafe for Memchr<'h>
impl<I> IntoIterator for Memchr<'h>
fn into_iter(self: Self) -> I
impl<T> Any for Memchr<'h>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Memchr<'h>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Memchr<'h>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Memchr<'h>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Memchr<'h>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Memchr<'h>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for Memchr<'h>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Memchr<'h>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Memchr<'h>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>